@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-import uuid
-
 from shadowsocks import protocol_flag as flag
 from shadowsocks.ciphers import SUPPORT_METHODS
 from shadowsocks.mdb.models import User
@@ -32,8 +30,6 @@ class CipherMan:
 
         self.cipher = None
         self._buffer = bytearray()
-        self.last_access_user = None
-        self.uuid = uuid.uuid4().hex
 
         if self.access_user:
             self.method = access_user.method
@@ -90,18 +86,25 @@ class CipherMan:
                 first_data = self._buffer
             salt = first_data[: self.cipher_cls.SALT_SIZE]
             if salt in self.bf:
-                raise RuntimeError(f"repeated salt founded!,peer:{self.peername}")
+                raise RuntimeError(
+                    f"repeated salt founded!,peer:{self.peername},{salt}"
+                )
             else:
                 self.bf.add(salt)
 
             access_user = User.find_access_user(
-                self.user_port, self.method, self.ts_protocol, first_data
+                self.user_port,
+                self.method,
+                self.ts_protocol,
+                first_data,
             )
 
-            if not access_user or access_user.enable is False:
+            if not access_user:
                 raise RuntimeError(
                     f"can not find enable access user: {self.user_port}-{self.ts_protocol}-{self.cipher_cls}"
                 )
+            if not access_user.enable:
+                raise RuntimeError(f"access user not have traffic: {access_user}")
             self.access_user = access_user
             self.record_user_ip(self.peername)
             self.incr_user_tcp_num(1)
