@@ -90,10 +90,10 @@ class LocalHandler:
         try:
             data = self.cipher.decrypt(data)
         except Exception as e:
-            self.close()
             logging.warning(
                 f"decrypt data error:{e} remote:{self._peername},type:{self._transport_protocol_human} closing..."
             )
+            self.close()
             return
 
         if not data:
@@ -113,41 +113,55 @@ class LocalHandler:
             logging.warning(f"unknown stage:{self._stage}")
 
     async def _handle_stage_init(self, data):
-        addr_type, dst_addr, dst_port, header_length = parse_header(data)
-        if not all([addr_type, dst_addr, dst_port, header_length]):
-            logging.warning(f"parse error addr_type: {addr_type} port: {self.port}")
+        atype, dst_addr, dst_port, header_length = parse_header(data)
+        if not all([atype, dst_addr, dst_port, header_length]):
+            logging.warning(
+                f"parse_header_error atype: {flag.get_atype_for_human(atype)} port: {self.port}"
+            )
             self.close()
             return
         else:
+            logging.info(
+                "parse_header_success atype: {} {} from: {} dst: {}:{}".format(
+                    self._transport_protocol_human,
+                    flag.get_atype_for_human(atype),
+                    self._peername[0],
+                    dst_addr,
+                    dst_port,
+                )
+            )
             payload = data[header_length:]
-        logging.debug(
-            f"HEADER: {addr_type} - {dst_addr} - {dst_port} - {self._transport_protocol}"
-        )
 
         loop = asyncio.get_running_loop()
         if self._transport_protocol == flag.TRANSPORT_TCP:
             self._stage = self.STAGE_CONNECT
             self._handle_stage_connect(payload)
             try:
-                _, remote_tcp = await loop.create_connection(
+                task = loop.create_connection(
                     lambda: RemoteTCP(self), dst_addr, dst_port
                 )
+                _, remote_tcp = await asyncio.wait_for(task, 5)
             except Exception as e:
                 self._stage = self.STAGE_ERROR
                 self.close()
-                logging.warning(f"connection failed, {type(e)} e: {e}")
+                logging.warning(
+                    f"connection_failed, {type(e)} e: {dst_addr}:{dst_port}"
+                )
             else:
                 self._remote = remote_tcp
         else:
             try:
-                await loop.create_datagram_endpoint(
+                task = loop.create_datagram_endpoint(
                     lambda: RemoteUDP(dst_addr, dst_port, payload, self),
                     remote_addr=(dst_addr, dst_port),
                 )
+                await asyncio.wait_for(task, 5)
             except Exception as e:
                 self._stage = self.STAGE_ERROR
                 self.close()
-                logging.warning(f"connection failed, {type(e)} e: {e}")
+                logging.warning(
+                    f"connection_failed, {type(e)} e: {dst_addr}:{dst_port}"
+                )
 
     def _handle_stage_connect(self, data):
         # 在握手之后，会耗费一定时间来来和remote建立连接,但是ss-client并不会等这个时间
@@ -159,7 +173,6 @@ class LocalHandler:
 
     def _handle_stage_stream(self, data):
         self._remote.write(data)
-        logging.debug(f"relay data length {len(data)}")
 
 
 class LocalTCP(asyncio.Protocol):
@@ -209,7 +222,6 @@ class RemoteTCP(asyncio.Protocol):
         self.local = local_handler
         self.peername = None
         self._transport = None
-        self.cipher = CipherMan(access_user=local_handler.cipher.access_user)
         self.ready = False
 
         self._is_closing = False
@@ -230,6 +242,9 @@ class RemoteTCP(asyncio.Protocol):
     def connection_made(self, transport: asyncio.Transport):
         self._transport = transport
         self.peername = self._transport.get_extra_info("peername")
+        self.cipher = CipherMan(
+            access_user=self.local.cipher.access_user, peername=self.peername
+        )
         transport.write(self.local._connect_buffer)
         self.ready = True
         CONNECTION_MADE_COUNT.inc()
